"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const JSON5 = require("json5");
const path_1 = require("path");
function parseCompareResult(inputFilePath) {
    let inputData;
    // read the compare.json file
    try {
        inputData = JSON5.parse(fs_extra_1.readFileSync(path_1.resolve(inputFilePath), "utf8"));
        // grab all control samples
        const controlData = inputData.find((element) => {
            return element.set === "control";
        });
        // grab all experiment samples
        const experimentData = inputData.find((element) => {
            return element.set === "experiment";
        });
        // throw if either control or experiment samples not found
        if (!controlData || !experimentData) {
            throw new Error(`Missing control or experiment set in compare.json`);
        }
        return {
            controlData,
            experimentData,
        };
    }
    catch (error) {
        throw new Error(`Cannot parse the compare.json file. Please make sure ${inputFilePath} is valid JSON`);
    }
}
exports.default = parseCompareResult;
//# sourceMappingURL=parse-compare-result.js.map